﻿/*
 *
 *
 *    GenericRadio.cs
 *
 *    AutoCap - A generic radio interface.
 *
 *    License: GNU General Public License Version 3.0.
 *    
 *    Copyright (C) 2014 by Matthew K. Roberts, KK5JY. All rights reserved.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful, but
 *    WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see: http://www.gnu.org/licenses/
 *    
 *
 */

using System;
using System.Globalization;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Net;

namespace KK5JY.AutoCap {
	/// <summary>
	/// A generic radio interface.
	/// </summary>
	/// <remarks>
	/// The generic key-value pairs used for each update message:
	///     Frequency=n  - indicates the radio frequency, measured in Hz
	/// </remarks>
	public sealed class GenericRadio : GenericConnector, IRadio, IReportsVersion, IDisposable {
		#region Public Properties
		/// <summary>
		/// Return the version string.
		/// </summary>
		public string VersionString {
			get { return String.Format("Generic Radio - {0}:{1}", EndPoint.Address, EndPoint.Port); }
		}

		/// <summary>
		/// The current frequency.
		/// </summary>
		public decimal Frequency { get; private set; }
		#endregion

		#region Public Methods
		/// <summary>
		/// Create a new sensor.
		/// </summary>
		/// <param name="ep">The host to which to connect.</param>
		public GenericRadio(IPEndPoint ep) : base(ep) {
			// nop
		}
		#endregion

		#region Event Handlers
		protected override void OnMalformedMessage(GenericMessageError e) {
			//
			//  TODO: increment a counter or something...
			//
		}

		protected override void OnMessageReceived(GenericMessageEvent e) {
			try {
				foreach (var kvp in e.Message) {
					if (String.Equals(kvp.Key, "Frequency", StringComparison.InvariantCultureIgnoreCase)) {
						Frequency = Decimal.Parse(kvp.Value, CultureInfo.InvariantCulture);
					}
				}
			} catch {
				//
				//  nop
				//
			}
		}
		#endregion
	}
}
